@@ -3,6 +3,7 @@ import grpc
 
 # Load ResInsight Processing Server Client Library
 import rips
+
 # Connect to ResInsight instance
 resInsight = rips.Instance.find()
 
@@ -24,7 +25,7 @@ params.user_ucs = 123
 
 # Loop through all cases
 for case in cases:
-    assert(isinstance(case, rips.GeoMechCase))
+    assert isinstance(case, rips.GeoMechCase)
     min_res_depth, max_res_depth = case.reservoir_depth_range()
 
     # Find a good output path
@@ -32,12 +33,18 @@ for case in cases:
     folder_name = os.path.dirname(case_path)
 
     # Import formation names
-    case.import_formation_names(formation_files=['D:/Projects/ResInsight-regression-test/ModelData/norne/Norne_ATW2013.lyr'])
+    case.import_formation_names(
+        formation_files=[
+            "D:/Projects/ResInsight-regression-test/ModelData/norne/Norne_ATW2013.lyr"
+        ]
+    )
 
     # create a folder to hold the snapshots
-    dirname = os.path.join(folder_name, 'snapshots')
+    dirname = os.path.join(folder_name, "snapshots")
     print("Exporting to: " + dirname)
 
-    for well_path in well_paths[0:4]: # Loop through the first five well paths
+    for well_path in well_paths[0:4]:  # Loop through the first five well paths
         # Create plot with parameters
-        wbsplot = case.create_well_bore_stability_plot(well_path=well_path.name, time_step=0, parameters=params)
\ No newline at end of file
+        wbsplot = case.create_well_bore_stability_plot(
+            well_path=well_path.name, time_step=0, parameters=params
+        )
