@@ -220,3 +220,11 @@ def test_selected_cells(rips_instance, initialize_test):
         # Try to read for SOIL the time step (will be empty since nothing is selected)
         soil_results = case.selected_cell_property("DYNAMIC_NATIVE", "SOIL", tidx)
         assert len(soil_results) == 0
+
+
+def test_multiple_load_of_same_case(rips_instance, initialize_test):
+    # Test related to issue https://github.com/OPM/ResInsight/issues/9332
+    path_name = dataroot.PATH + "/flow_diagnostics_test/SIMPLE_SUMMARY2.EGRID"
+    case_count = 3
+    for i in range(case_count):
+        case = rips_instance.project.load_case(path_name)
